@@ -3,7 +3,8 @@ import cytoolz
 
 from cytoolz import curry, identity, keyfilter, valfilter, merge_with
 from cytoolz.utils import raises
-from dev_skip_test import dev_skip_test
+
+from .dev_skip_test import dev_skip_test
 
 
 # `cytoolz` functions for which "# doctest: +SKIP" were added.
@@ -15,7 +16,7 @@ skipped_doctests = ['get_in']
 @curry
 def isfrommod(modname, func):
     mod = getattr(func, '__module__', '') or ''
-    return modname in mod
+    return mod.startswith(modname) or 'toolz.functoolz.curry' in str(type(func))
 
 
 def convertdoc(doc):
@@ -49,8 +50,10 @@ def test_docstrings_uptodate():
     d = merge_with(identity, toolz_dict, cytoolz_dict)
     for key, (toolz_func, cytoolz_func) in d.items():
         # only check if the new doctstring *contains* the expected docstring
-        toolz_doc = convertdoc(toolz_func)
-        cytoolz_doc = cytoolz_func.__doc__
+        # in Python < 3.13 the second line is indented, in 3.13+
+        # it is not, strip all lines to fudge it
+        toolz_doc = "\n".join(line.strip() for line in convertdoc(toolz_func).splitlines())
+        cytoolz_doc = "\n".join(line.strip() for line in cytoolz_func.__doc__.splitlines())
         if toolz_doc not in cytoolz_doc:
             diff = list(differ.compare(toolz_doc.splitlines(),
                                        cytoolz_doc.splitlines()))
@@ -68,7 +71,7 @@ def test_docstrings_uptodate():
                              key in skipped_doctests))
 
             if any(map(checkbad, diff)):
-                assert False, 'Error: cytoolz.%s has a bad docstring:\n%s\n' % (
+                assert False, 'Error: cytoolz.{} has a bad docstring:\n{}\n'.format(
                     key, '\n'.join(fulldiff))
 
 
